%define grass 83
%global __requires_exclude .*libgrass_.*

# Doesnt build with -j16, does with -j12 or lower, we choose -j12
%global make_build %(cpus=%_smp_mflags;if [ "${cpus##-j}" -gt 12 ];then echo make -j12;else echo make $cpus;fi)

# we don't want to provide private python extension libs
%define _exclude_files_from_autoprov %{python2_sitearch}/.*\\.so\\|%{python3_sitearch}/.*\\.so
%define _requires_exceptions devel\(.*\)
%define _provides_exceptions devel\(.*\)


# Force the python interpreter to python3:
%global __python %{__python3}
%global configure_with_spatialite -D WITH_QSPATIALITE:BOOL=TRUE

Name:               qgis
Version:            3.36.1
Release:            %mkrel 2
Summary:         Geographic Information System for Linux/Unix
License:            GPLv2+
Group:              Sciences/Geosciences
URL:                 https://qgis.org/
Source1:            %{name}-mime.xml
Source2:            org.qgis.qgis.desktop
Patch0:         qgis-3.22.6-set-sip-binary-path.patch

BuildRequires:  cmake
BuildRequires:  grass
BuildRequires:  imagemagick
BuildRequires:  flex
BuildRequires:  bison
BuildRequires:  mlocate
BuildRequires:  postgis
BuildRequires:  dos2unix
BuildRequires:  txt2tags
BuildRequires:  qscintilla-qt5-devel
BuildRequires:  spatialindex-devel
BuildRequires:  postgresql-devel
BuildRequires:  draco-devel
BuildRequires:  geos-devel
BuildRequires:  pkgconfig(cfitsio)
BuildRequires:  libfcgi-devel
BuildRequires:  lib64qt5keychain-devel
BuildRequires:  lib64qwt-qt5-devel
BuildRequires:  lib64gdal-devel >= 2.1
BuildRequires:  pkgconfig(libzip)
BuildRequires:  pkgconfig(proj)
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(gsl)
BuildRequires:  pkgconfig(netcdf)
BuildRequires:  lib64qwt-devel
BuildRequires:  pkgconfig(Qt53DCore)
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Help)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5QuickWidgets)
BuildRequires:  pkgconfig(Qt5SerialPort)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5UiTools)
BuildRequires:  pkgconfig(Qt5WebKit)
BuildRequires:  pkgconfig(Qt5WebKitWidgets)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(Qt5XmlPatterns)
BuildRequires:  pkgconfig(spatialite)
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3-sip6 >= 6.7.2
BuildRequires:  python3-biopython-sql
BuildRequires:  python3-qt5-qscintilla
BuildRequires:  python3-qt5-devel
BuildRequires:  python3-gdal
BuildRequires:  python3-six
BuildRequires:  lib64qca2-qt5-devel
BuildRequires:  qca2-qt5
BuildRequires: lib64protobuf-devel
BuildRequires: lib64exiv2-devel
BuildRequires: lib64pdal-devel
BuildRequires: sd
BuildRequires: exiv2
Requires:       python3-biopython-sql
Requires:       postgis
Requires:       gdal
Requires:       pdal
Requires:       gpsbabel
Requires:       python3-qgis
Requires:       python3-gdal
Requires:       qca2-qt5
Requires:       python3-pyproj
Requires:       python3-OWSLib
Requires:       python3-pyqt5-sip
Requires:       python3-psycopg2
Requires:       python3-urllib3
Requires:       python3-idna

%description
Geographic Information System (GIS) manages, analyzes, and displays
databases of geographic information. Quantum GIS (QGIS) supports shape file
viewing and editing, spatial data storage with PostgreSQL/PostGIS, projection
on-the-fly, map composition, and a number of other features via a plugin
interface. QGIS also supports display of various geo-referenced raster and
Digital Elevation Model (DEM) formats including GeoTIFF, Arc/Info ASCII Grid,
and USGS ASCII DEM.

%files
%doc
%{_bindir}/%{name}*
%{_libdir}/lib%{name}_*.so.*
%{_libdir}/%{name}/
%{_qt5_plugindir}/designer/libqgis_customwidgets.so.*
%{_datadir}/%{name}/
%{_datadir}/applications/*.desktop
%{_datadir}/metainfo/*.xml
%{_iconsdir}/hicolor/*/apps/*
%{_iconsdir}/hicolor/*/mimetypes/*
%{_datadir}/mime/packages/%{name}.xml
%{_mandir}/man1/*.1*
%exclude %{_libdir}/%{name}/grass
%exclude %{_datadir}/%{name}/python
%exclude %{_datadir}/%{name}/grass
%exclude %{_datadir}/%{name}/FindQGIS.cmake

#---------------------------------------------------------

%package devel
Summary:    Development libraries and headers for QGIS
Group:      Sciences/Geosciences
Requires:   %{name} = %version
Requires:   %{name}-grass = %version
Requires:   python3-%{name} = %version

%description devel
Development headers for QGIS.

%files devel
%{_includedir}/%{name}/
%{_libdir}/lib%{name}_*.so
%{_libdir}/libqgisgrass*.so
%{_libdir}/libqgispython.so
%{_datadir}/%{name}/FindQGIS.cmake
%{_qt5_plugindir}/designer/libqgis_customwidgets.so

#---------------------------------------------------------

%package grass
Summary:    QGIS plugins for accessing GRASS data
Group:      Sciences/Geosciences
Requires:   grass >= 8.0.0

%description grass
This package provides plugins for QGIS that provide access to GRASS data from
within QGIS.

%files grass
%{_libdir}/libqgisgrass*.so.*
%{_libdir}/%{name}/grass/
%{_datadir}/%{name}/grass/

#---------------------------------------------------------

%package -n python3-qgis
Summary:    Python 3 integration and plugins for qgis
Group:      Sciences/Geosciences
Requires:   %{name} = %{version}-%{release}
Requires:   python3-sip6 >= 6.7.2
Requires:   python3-qt5
Requires:   python3-httplib2
Requires:   python3-jinja2
Requires:   python3-matplotlib
Requires:   python3-qt5-qscintilla
Requires:   python3-pytz
Requires:   python3-gdal
Requires:   python3-six
Requires:   python3-dateutil
Requires:   python3-markupsafe
Requires:   python3-pygments
Requires:   python3-pyyaml
Requires:   python3-psycopg2
Obsoletes:  qgis-python 

Obsoletes:  python-qgis
Provides:   python-qgis = %{version}-%{release}

%description -n python3-qgis
Python 3 integration and plugins for qgis.

%files -n python3-qgis
%{_libdir}/libqgispython.so.*
%{_datadir}/%{name}/python/
%{python3_sitearch}/%{name}/
%{python3_sitearch}/PyQt5/uic/widget-plugins/
%dir %{python3_sitearch}/PyQt5/uic

#---------------------------------------------------------

%prep


%build
export LDFLAGS="-L/usr/lib64/libglvnd/ $LDFLAGS"
pushd %_sourcedir
wget -nc https://qgis.org/downloads/qgis-%{version}.tar.bz2
tar -xjf qgis-%{version}.tar.bz2 -C %_builddir
popd

pushd %_builddir/qgis-%{version}
%autopatch -p1

%cmake_qt5 \
    -Wno-dev \
    -DQGIS_LIB_SUBDIR=%{_lib} \
    -DQGIS_MANUAL_SUBDIR=/share/man \
    -DQGIS_PLUGIN_SUBDIR=%{_lib}/qgis \
    -DQGIS_CGIBIN_SUBDIR=%{_lib}/qgis \
    -DSIP_BINARY_PATH=%{_bindir}/sip-build \
    -DQSCI_SIP_DIR=%{python3_sitearch}/PyQt5 \
    -DQWT_INCLUDE_DIR=%{_includedir}/qwt \
    -DWITH_GRASS=TRUE \
    -DGRASS_PREFIX8=%{_libdir}/grass%{grass} \
    -DCMAKE_SKIP_RPATH=OFF \
    -DWITH_BINDINGS=ON \
    -DBINDINGS_GLOBAL_INSTALL=ON \
    -DWITH_3D=ON \
    -DWITH_CUSTOM_WIDGETS=ON \
    -DUSE_OPENCL=OFF \
    -DENABLE_TESTS=OFF 
    
%make_build
popd


%install
pushd %_builddir/qgis-%{version}
%make_install -C build
popd

install -m 0644 %SOURCE2 %{buildroot}%{_datadir}/applications/org.qgis.qgis.desktop

# Install MIME type definitions
install -d %{buildroot}%{_datadir}/mime/packages
install -pm0644 %{SOURCE1} %{buildroot}%{_datadir}/mime/packages/%{name}.xml

# Remove install instructions
rm -f %{buildroot}%{_datadir}/%{name}/doc/INSTALL*


%changelog
* Sun Mar 31 2024  pp - 3.36.1-2pclos2024
- rebuild against new pdal

* Fri Mar 22 2024  pp - 3.36.1-1pclos2024
- new version

* Thu Mar 14 2024  pp - 3.36.0-3pclos2024
- rebuild against new grass

* Tue Mar 05 2024  pp - 3.36.0-2pclos2024
- rebuild against new proj

* Fri Feb 23 2024  pp - 3.36.0-1pclos2024
- new version

* Fri Jan 19 2024  pp - 3.34.3-1pclos2024
- new version

* Fri Jan 12 2024  pp - 3.34.2-3pclos2024
- rebuilt against updates

* Wed Dec 27 2023 pp - 3.34.2-2pclos2024
- rebuilt against new gdal

* Fri Dec 22 2023 pp - 3.34.2-1pclos2024
- new version

* Wed Nov 29 2023 pp - 3.34.1-2pclos2023
- rebuild against new spatialite

* Fri Nov 24 2023 pp - 3.34.1-1pclos2023
- new version

* Sat Oct 28 2023 pp - 3.34.0-1pclos2023
- new version

* Tue Sep 19 2023 pp - 3.32.3-1pclos2023
- new version

* Fri Aug 18 2023 pp - 3.32.2-1pclos2023
- new version

* Fri Jul 21 2023 pp - 3.32.1-1pclos2023
- new version

* Tue Jul 11 2023 pp - 3.32.0-2pclos2023
- rebuild against new grass

* Wed Jun 28 2023 pp - 3.32.0-1pclos2023
- new version

* Fri May 26 2023 pp - 3.30.3-1pclos2023
- new version

* Thu May 11 2023 pp - 3.30.2-2pclos2023
- rebuilt against new gdal

* Fri Apr 28 2023 pp - 3.30.2-1pclos2023
- new version

* Fri Mar 31 2023 pp - 3.30.1-1pclos2023
- new version

* Tue Mar 07 2023 pp - 3.30.0-1pclos2023
- new version

* Fri Mar 03 2023 pp - 3.28.4-1pclos2023
- new version

* Fri Jan 27 2023 pp - 3.28.3-1pclos2023
- new version

* Tue Jan 03 2023 pp - 3.28.2-4pclos2023
- rebuild against rebuilt GRASS
- removed __devel_exclude_path

* Thu Dec 29 2022 pp - 3.28.2-3pclos2023
- add MGA patches
- rebuild against new gsl

* Wed Dec 28 2022 tex - 3.28.2-2pclos2023
- add req python3-idna

* Fri Dec 16 2022 pp - 3.28.2-1pclos2022
- new version

* Wed Dec 14 2022 tex - 3.28.1-3pclos2022
- add req python3-urllib3

* Thu Dec 08 2022 pp - 3.28.1-2pclos2022
- rebuild against new gdal, proj

* Fri Nov 18 2022 pp - 3.28.1-1pclos2022
- new version
